@@ -98,7 +98,7 @@ semLm <- function(formula, data, classes, burnin = 40, samples = 200, trafo = "N
   lambda <- result_lambda <- b.lambda <- m.lambda <- se <- ci <- NULL
 
   if (trafo == "log") {
-    classes <- log.est(y = classes)
+    classes <- logEst(y = classes)
   }
   if (trafo == "bc") {
     lambda.est <- lambda.lm.est(
